@@ -1,4 +1,4 @@
-# $Id: LDAP.pm 43956 2015-10-02 13:25:27Z wsl $
+# $Id: LDAP.pm 42262 2014-09-18 15:18:19Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/LDAP.pm $
 
 package Aselect::LDAP;
@@ -138,45 +138,41 @@ sub attributes {
 
 	my $ldap = $self->connection;
 
+	my $schema = $self->schema;
+	my $canon = $self->canon;
+
 	my %req;
 	my %attrs;
 	my %substs;
-	while(my ($key, $vals) = each(%$attributes)) {
-		ATTR: foreach my $val (@$vals) {
-			my %s;
-			my $attrs = scan($val);
-			foreach my $a (@$attrs) {
-				my $c = $self->canonicalize($a);
-				next ATTR unless defined $c;
-				undef $s{$c};
-				undef $attrs{$c};
-				$c =~ s/;.*//;
-				undef $req{$c};
-			}
-			push @{$substs{$key}}, [$val, \%s];
+	ATTR: while(my ($key, $val) = each(%$attributes)) {
+		my %s;
+		my $attrs = scan($val);
+		foreach my $a (@$attrs) {
+			my $c = $self->canonicalize($a);
+			next ATTR unless defined $c;
+			undef $s{$c};
+			undef $attrs{$c};
+			$c =~ s/;.*//;
+			undef $req{$c};
 		}
+		$substs{$key} = \%s;
 	}
 
 	my $search = $self->search($uid, [keys %req]);
 	return [] unless $search->count;
 
-	# should be only one entry
+	# should be only one
 	foreach my $entry ($search->entries) {
 		foreach my $a (keys %attrs) {
 			$attrs{$a} = $entry->get_value($a, asref => 1) || [];
 		}
 	}
 
-	my $canon = $self->canon;
-
 	my @res;
-	while(my ($key, $substs) = each(%substs)) {
-		foreach my $subst (@$substs) {
-			my ($val, $s) = @$subst;
-			my @s = keys %$s;
-			my %s; @s{@s} = @attrs{@s};
-			push @res, map { $key, $_ } replace($val, \%s, $canon);
-		}
+	while(my ($key, $val) = each(%substs)) {
+		my @a = keys %$val;
+		my %a; @a{@a} = @attrs{@a};
+		push @res, map { $key, $_ } replace($attributes->{$key}, \%a, $canon);
 	}
 	return \@res;
 }
