@@ -1,4 +1,4 @@
-# $Id: Request.pm 42522 2014-11-10 10:42:01Z wsl $
+# $Id: Request.pm 36180 2011-12-08 13:57:04Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Cancel/Request.pm $
 
 use strict;
@@ -9,7 +9,6 @@ package Aselect::UI::Cancel::Request;
 
 use Aselect::Request -self;
 
-use constant uid => undef;
-use constant credentials => 'canceled';
-
 bool_param cancel;
+
+const credentials => 'canceled';
