@@ -1,4 +1,4 @@
-# $Id: Document.pm 36341 2012-01-15 18:20:01Z wsl $
+# $Id: Document.pm 42299 2014-09-26 14:30:54Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Document.pm $
 
 use strict;
@@ -24,11 +24,17 @@ sub transform {
 }
 
 sub build {
+	my $name = $self->rootname;
+	my $root = $self->construct($name);
+	$self->setDocumentElement($root);
+
 	$self->hook_next;
+
+	$root = $self->documentElement;
+	$name = $root->nodeName;
+
 	my $cfg = $self->cfg;
 	my $req = $self->req;
-	my $root = $self->documentElement;
-
 	$root->appendChild($self->construct(settings =>
 		[warn => $req->new_warn],
 		[remember => $req->new_remember],
@@ -41,19 +47,15 @@ sub build {
 	if(my $uid = $ticket->uid) {
 		my $exp = $ticket->expiration;
 
-		my $session = $self->construct(session =>
+		$root->appendChild($self->construct(session =>
 			[uid => $uid],
 			[organization => $cfg->organization],
-			[start => iso8601(localtime($exp))],
-			[end => iso8601(localtime($exp + $cfg->session_timeout))],
-		);
-
-		$root->appendChild($session);
+			[start => iso8601(gmtime($exp)) . ' GMT'],
+			[end => iso8601(gmtime($exp + $cfg->session_timeout)) . ' GMT'],
+		));
 	}
 
-	my $name = $root->nodeName;
-	$name =~ tr|:|/|;
-	eval { $self->transform($name) };
+	eval { $self->transform($name =~ tr|:|/|r) };
 	warn $@ if $@;
 }
 
