@@ -1,4 +1,4 @@
-# $Id: HTTP.pm 47630 2018-06-25 14:37:01Z wsl $
+# $Id: HTTP.pm 36089 2011-11-23 19:23:06Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Error/HTTP.pm $
 
 use strict;
@@ -11,14 +11,13 @@ use Aselect::UI::Error -self;
 
 field number;
 
-use constant type => 'http';
+sub type { 'http' }
 sub args {
-	my $req = $self->req;
 	return {
 		number => $self->number,
-		url => $req->url,
-		page => $req->virtual_path,
-	};
+		url => $self->req->url,
+		page => $self->req->path_translated,
+	}
 }
 
 sub response {
