@@ -1,5 +1,5 @@
-# $Id: Request.pm 35974 2011-11-12 12:23:29Z wsl $
-# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/Logout/Request.pm $
+# $Id: Request.pm 39279 2013-04-22 14:14:52Z wsl $
+# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Logout/Request.pm $
 
 use strict;
 use warnings FATAL => 'all';
@@ -9,7 +9,7 @@ package Aselect::UI::Logout::Request;
 
 use Aselect::URL qw(normalize_url valid_http_url);
 
-use Aselect::UI::Request -self;
+use Aselect::Request -self;
 
 sub uid {
 	my $session = $self->cur_session;
@@ -38,16 +38,18 @@ param service => sub {
 	my $cfg = $self->cfg;
 
 	$_ = normalize_url($_);
-	die $self->error('service')
+	die $self->errorpage('service')
         unless valid_http_url($_);
 
 	my $re = $cfg->urlfilter;
-	die $self->error('service')
+	die $self->errorpage('service')
 		unless $_ =~ $re;
 
 	$re = $cfg->servicefilter;
-	die $self->error('service')
+	die $self->errorpage('service')
 		unless $_ =~ $re;
+
+	$_ = $self->apply_https_everywhere($_);
 };
 
 field effective_warn => sub {
